/*1. Create master panel codes dataset that has the ids and only keeps the countries in the project. 
2. merge this with meta datat on the regions (from the WDI)
3. create the fertility dataset
4. merge this with the master (note I create all datasets early in the code then merge them all later)
*/ 

*put your directory down
cd "/Users/dawno/Desktop/exforbeth"


*************************************************************************
 *Bring in Panel Codes for merging 
*************************************************************************

 import excel "./master_rep.xlsx", sheet("Panel Codes") firstrow clear case(lower)
 
*I have my own column for whether that country is in the project or not, so that I can easily erase irrelevant countries. 
count if inproject!=. 
keep if inproject!=. 

*ccode is the unique country ID I use, make sure it is unique
isid ccode

save  "./clean/panelcodes", replace

*************************************************************************
*Bring in meta data for regions etc. 
*************************************************************************

import excel "./master_rep.xlsx", sheet("Metadata - Countries") firstrow clear

*merge regions with the panelcodes
merge 1:1 ccode using "./clean/panelcodes"
*only 53 matched because that is all I use in the project. Drop the rest. 
keep if inproject!=.
drop _m 
drop Special
save  "./clean/panelcodes", replace


*************************************************************************
*Fertility
*************************************************************************

import excel "./master_rep.xlsx", sheet("WDI_fertility") firstrow clear 

merge m:1 ccode using "./clean/panelcodes.dta"
 keep if _m==3
 drop _m
 
 *have to change the variable letters to the years they represent. for merge to work need it to be f1960 or fert1960, NOT f_1960 or fert_1960. 
 
 local i=1959
 foreach var of varlist E-BF {
 local i=`i'+1
 ren `var' fert`i'
 }
 
 *note on this code that since the first year I have is 1960 I make a local macro of 1959 to begin and then the loop ticks up a single number each time it is activated. All the loop does is rename the letter E into fert1960, f into fert1961 etc. 
 
 keep ccode fert*  
*i.e. drop all the other metadata


 reshape long fert, i(ccode) j(year) 
 
 save "./clean/fertility.dta", replace
 
*************************************************************************
*GDP
*From Penn World Tables 
*Heston, Summers, and Aten PWT 7.1
*Dates 1990-2009

*Alan Heston, Robert Summers and Bettina Aten, Penn World Table Version 7.1, Center for International Comparisons of Production, Income and Prices at the University of Pennsylvania, Nov 2012.

*They are using a different set of country codes, with ARG for argentina etc. 

import excel "./master_rep.xlsx", sheet("gdp") firstrow clear case(lower)


destring rgdpl rgdpl2 rgdpch, ignore("na") replace

la var pop "population"
la var  rgdpl "GDPpc, 2005 prices"
g lpop=log(pop)
la var lpop "Population (ln)"
g lgdppc = log(rgdpl)
la var  lgdppc "GDP per capita, 2005 (ln)"
keep  ccode year pop rgdpl lpop lgdppc country
replace ccode="DEU" if ccode=="GER" 


merge m:1 ccode using "./clean/panelcodes.dta"
keep if _m==3
drop _m
save "./clean/gdp", replace




*************************************************************************
*MERGING ALL DATASETS TOGETHER
*Note, here fertility is already merged with the panel codes, but if you have more than one you will merge these together later. 
*************************************************************************

use "./clean/gdp"


*merge with fertility
merge m:m ccode year using "./clean/fertility"
drop _m

save "./master_rep.dta", replace
*note this puts it in the main folder rather than the clean folder. 
